@@ -20,7 +20,7 @@
 using namespace PimCommon;
 
 GenericPlugin::GenericPlugin(QObject *parent)
-    : QObject(parent)
+    : AbstractGenericPlugin(parent)
 {
 
 }
@@ -29,4 +29,3 @@ GenericPlugin::~GenericPlugin()
 {
 
 }
-
